var class_ogre_1_1_texture_unit_state =
[
    [ "TextureEffect", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect.html", "struct_ogre_1_1_texture_unit_state_1_1_texture_effect" ],
    [ "TextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a162e712b66645d1faa9f11c270ad2794", null ],
    [ "UVWAddressingMode", "class_ogre_1_1_texture_unit_state.html#ac60c0a3508a6ff12f8dac4668df9dd79", null ],
    [ "EffectMap", "class_ogre_1_1_texture_unit_state.html#a76b0d087ff12f806b0bd5e8b97d466bf", null ],
    [ "TextureEffectType", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626", [
      [ "ET_ENVIRONMENT_MAP", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a2f0676d96ba378e32c3087fff9b7e73e", null ],
      [ "ET_PROJECTIVE_TEXTURE", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626ae6f4dff5b324b7aa28253c37702a5131", null ],
      [ "ET_UVSCROLL", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626addf3dd2bc4eeabca2968c71600c347aa", null ],
      [ "ET_USCROLL", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626ab5e67e4d891aad2e60925b216de34f08", null ],
      [ "ET_VSCROLL", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a97f8687c21d13e08b89d22902919acaa", null ],
      [ "ET_ROTATE", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a9afa2c9da615898c1a045e19bb3e602b", null ],
      [ "ET_TRANSFORM", "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626a97cd551c90f9f6000fe231f542815852", null ]
    ] ],
    [ "EnvMapType", "class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931e", [
      [ "ENV_PLANAR", "class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931ea50895f1c891eedb007500965ca4c204a", null ],
      [ "ENV_CURVED", "class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931ea5a2d57450ada903ba586826344b7dbcb", null ],
      [ "ENV_REFLECTION", "class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931ea3983cce37fbce61c118d202278166be9", null ],
      [ "ENV_NORMAL", "class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931eae1644f418a586fea471d808485a7a036", null ]
    ] ],
    [ "TextureTransformType", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82d", [
      [ "TT_TRANSLATE_U", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82da46631ede4b31d448ebb891daf94cd526", null ],
      [ "TT_TRANSLATE_V", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82da81757d80ac644a8da31f107a9cc21fdc", null ],
      [ "TT_SCALE_U", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82da7160eae1144aeb0cb6428416e465fd88", null ],
      [ "TT_SCALE_V", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82da6e85f00afb893c2bace9a394e5ac9f95", null ],
      [ "TT_ROTATE", "class_ogre_1_1_texture_unit_state.html#a942a1ce66d0909d29ed09c98e9e6d82daecf829c4f898451d496f56e774e0eacf", null ]
    ] ],
    [ "TextureCubeFace", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3", [
      [ "CUBE_FRONT", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3aa9d74ce7d0576d0dda5b5046a6434529", null ],
      [ "CUBE_BACK", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a4459a171ecd0fe942dc5b5f8e517ecb2", null ],
      [ "CUBE_LEFT", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a2062c3ecab68e4d86345293283f69a19", null ],
      [ "CUBE_RIGHT", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a5044b1ee092361549f2ea953ed344b0a", null ],
      [ "CUBE_UP", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3ab085d126cff272045a1e616adbd2d726", null ],
      [ "CUBE_DOWN", "class_ogre_1_1_texture_unit_state.html#a2584766311cf6d0eaada7be28c287cc3a819e8a0cf0892c671d2fb4835780a12a", null ]
    ] ],
    [ "BindingType", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8", [
      [ "BT_FRAGMENT", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8a39c5f87a9b1c5873ece87f48cba19970", null ],
      [ "BT_VERTEX", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8a857de1fa5e307a5a5b0df779ad4a470e", null ],
      [ "BT_GEOMETRY", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8a44dd1976abdef621f899dbd5b07cf2a6", null ],
      [ "BT_TESSELLATION_HULL", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8a64c2b3822fbb577f7ed8749e82b9119a", null ],
      [ "BT_TESSELLATION_DOMAIN", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8ab49cb1270c042c02e106a0af5feb2627", null ],
      [ "BT_COMPUTE", "class_ogre_1_1_texture_unit_state.html#a411bcf3e69280ce146f09ddc73d9e7e8a0d13c803665b5063d1f2a9317bed2737", null ]
    ] ],
    [ "ContentType", "class_ogre_1_1_texture_unit_state.html#a35a108a68c71c8267af4af8c1a819030", [
      [ "CONTENT_NAMED", "class_ogre_1_1_texture_unit_state.html#a35a108a68c71c8267af4af8c1a819030a1bffc0ebc06c072fd00b5e032ba3ce01", null ],
      [ "CONTENT_SHADOW", "class_ogre_1_1_texture_unit_state.html#a35a108a68c71c8267af4af8c1a819030a781de9de8d083db90677da1176d8ba82", null ],
      [ "CONTENT_COMPOSITOR", "class_ogre_1_1_texture_unit_state.html#a35a108a68c71c8267af4af8c1a819030a56ccbe92a25c96ed721ecbe17301bfc1", null ]
    ] ],
    [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a310855c1a22c81688d276cbaf62bd1bb", null ],
    [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a474f19d881bffa023e05852ad94c727a", null ],
    [ "~TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a21c2ac927f9f93472af7c8554c73bb0e", null ],
    [ "TextureUnitState", "class_ogre_1_1_texture_unit_state.html#a9b8a41ad39710320e10738f0a7d96f0d", null ],
    [ "operator=", "class_ogre_1_1_texture_unit_state.html#aba48cec6d1b8ce8973b0fa1dac2312b7", null ],
    [ "getTextureName", "class_ogre_1_1_texture_unit_state.html#ad5215e862e9de0e2449835cbc579afef", null ],
    [ "setTextureName", "class_ogre_1_1_texture_unit_state.html#aa2261f5949b6e8185e46999b7ddaf93f", null ],
    [ "setTexture", "class_ogre_1_1_texture_unit_state.html#a5da15b05f88f28597b0eb6e400e6242a", null ],
    [ "setCubicTextureName", "class_ogre_1_1_texture_unit_state.html#aef7c395bc62173060141717a79681a97", null ],
    [ "setCubicTextureName", "class_ogre_1_1_texture_unit_state.html#ae19baf627a3dffd5795985bb16f4967b", null ],
    [ "setCubicTexture", "class_ogre_1_1_texture_unit_state.html#a9f64f66afe24fa8f6bbf0141d8602649", null ],
    [ "setAnimatedTextureName", "class_ogre_1_1_texture_unit_state.html#a50e1e1cd7feecd8b4c1f914b5c361413", null ],
    [ "setAnimatedTextureName", "class_ogre_1_1_texture_unit_state.html#a71b18f9c8f0bcfc7324b5ebbcee40ae3", null ],
    [ "getTextureDimensions", "class_ogre_1_1_texture_unit_state.html#ab5264a89056790b0c74553b92e65b12e", null ],
    [ "setCurrentFrame", "class_ogre_1_1_texture_unit_state.html#a040a7a49541296837b3e0a0289b7c4c8", null ],
    [ "getCurrentFrame", "class_ogre_1_1_texture_unit_state.html#a66a53409852d79a7f02a8c19dc405092", null ],
    [ "getFrameTextureName", "class_ogre_1_1_texture_unit_state.html#a03743bd89016116355b7d2cc4eb97006", null ],
    [ "setFrameTextureName", "class_ogre_1_1_texture_unit_state.html#affd8342a0a86bc34f727dc6b4b21f565", null ],
    [ "addFrameTextureName", "class_ogre_1_1_texture_unit_state.html#a8532ad689770975afe46a3ddd49123a8", null ],
    [ "deleteFrameTextureName", "class_ogre_1_1_texture_unit_state.html#a7997d8a1385a7538a443c74d94a7cf75", null ],
    [ "getNumFrames", "class_ogre_1_1_texture_unit_state.html#a2f6eecd5b329f25365bd6b3a4050cd1b", null ],
    [ "setBindingType", "class_ogre_1_1_texture_unit_state.html#a0ab7a2779ea196f2d51435d12a02d81f", null ],
    [ "getBindingType", "class_ogre_1_1_texture_unit_state.html#a3b5783f584c51bed687ec033bda01f1c", null ],
    [ "setContentType", "class_ogre_1_1_texture_unit_state.html#adfaae68c0291e96fb75ba217d94e67bf", null ],
    [ "getContentType", "class_ogre_1_1_texture_unit_state.html#a1550b60ebc8506c725b1157e02c8eb6b", null ],
    [ "isCubic", "class_ogre_1_1_texture_unit_state.html#afe0aa6be6db7207ca6d439b6e52d33d8", null ],
    [ "is3D", "class_ogre_1_1_texture_unit_state.html#a6decf13e49ebeafb9556479fb2022286", null ],
    [ "getTextureType", "class_ogre_1_1_texture_unit_state.html#a702d2aee57c42cff6f34be00dc175fbc", null ],
    [ "setDesiredFormat", "class_ogre_1_1_texture_unit_state.html#a09a45c146f4e26397d2f5b0d885bd893", null ],
    [ "getDesiredFormat", "class_ogre_1_1_texture_unit_state.html#a485e6e427102e4b59d0225db39376c0f", null ],
    [ "setNumMipmaps", "class_ogre_1_1_texture_unit_state.html#aca6e1c5091f01b523e71952a17ad635b", null ],
    [ "getNumMipmaps", "class_ogre_1_1_texture_unit_state.html#ac3823882187ae6499feacd94366f0410", null ],
    [ "setIsAlpha", "class_ogre_1_1_texture_unit_state.html#a14b38dfbd84aec82f1bbe9f34e121180", null ],
    [ "getIsAlpha", "class_ogre_1_1_texture_unit_state.html#a25ac216db34ab5471ba58903061c38f2", null ],
    [ "getGamma", "class_ogre_1_1_texture_unit_state.html#a48e4c2e1ff89ed2653cf0238da7bb21f", null ],
    [ "setGamma", "class_ogre_1_1_texture_unit_state.html#a3859b558bf648b9825136156d9ebcae1", null ],
    [ "setHardwareGammaEnabled", "class_ogre_1_1_texture_unit_state.html#a09d08169e1c108c435fa595a227e87ad", null ],
    [ "isHardwareGammaEnabled", "class_ogre_1_1_texture_unit_state.html#a073cf9903b594cf1bb08b703934bf62d", null ],
    [ "getTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#a4b56b581407240e7b5139d779e1d2a8f", null ],
    [ "setTextureCoordSet", "class_ogre_1_1_texture_unit_state.html#a70c55b5db14e54e2e7a991f548b6387d", null ],
    [ "setTextureTransform", "class_ogre_1_1_texture_unit_state.html#ac7f99a83fe25f06af508b55e3ab381da", null ],
    [ "getTextureTransform", "class_ogre_1_1_texture_unit_state.html#a4636d2377419dcff47a0d55ae840d4d7", null ],
    [ "setTextureScroll", "class_ogre_1_1_texture_unit_state.html#a354b3466d8c49e6f0057dea8206d3dd4", null ],
    [ "setTextureUScroll", "class_ogre_1_1_texture_unit_state.html#a8b8123ca656ea172565cb6d4e9ef8224", null ],
    [ "getTextureUScroll", "class_ogre_1_1_texture_unit_state.html#a3ea082c5d8faf352a6e23d35e443056c", null ],
    [ "setTextureVScroll", "class_ogre_1_1_texture_unit_state.html#a83752e3f64f9a345abbfd143f213f586", null ],
    [ "getTextureVScroll", "class_ogre_1_1_texture_unit_state.html#a4f191c61087ac4bdbbad78b758b43244", null ],
    [ "setTextureUScale", "class_ogre_1_1_texture_unit_state.html#a112573713ccb2f221acf4a6d4c95c64c", null ],
    [ "getTextureUScale", "class_ogre_1_1_texture_unit_state.html#ab7996e6ea470360d7b772b4bb27e2aad", null ],
    [ "setTextureVScale", "class_ogre_1_1_texture_unit_state.html#af73cbd6d4bc2dbf21596da3a8d0dc4fd", null ],
    [ "getTextureVScale", "class_ogre_1_1_texture_unit_state.html#ab9fca20cb5698d2583a1496c61f830bb", null ],
    [ "setTextureScale", "class_ogre_1_1_texture_unit_state.html#aa5be6f7e13179f692c9af7c494c703cf", null ],
    [ "setTextureRotate", "class_ogre_1_1_texture_unit_state.html#a9239845b4de453c450e40f2c5f46cc8d", null ],
    [ "getTextureRotate", "class_ogre_1_1_texture_unit_state.html#a35f96567f246a00d967afcafccf242eb", null ],
    [ "getSampler", "class_ogre_1_1_texture_unit_state.html#aa88ea41c2ca613564f61c4b0d8b24203", null ],
    [ "setSampler", "class_ogre_1_1_texture_unit_state.html#a2b3791c291aef832a03eb4582d71ed33", null ],
    [ "getTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#ad25d04ad14d562c9e55d18da5695c898", null ],
    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a06aef1d348eb56c1289c5791013bb1f7", null ],
    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#af8ab090b0fee62a2a330d07161a2d10c", null ],
    [ "setTextureAddressingMode", "class_ogre_1_1_texture_unit_state.html#a5a54ece0b8cfb20f6dcddbd68813be43", null ],
    [ "setTextureBorderColour", "class_ogre_1_1_texture_unit_state.html#a4685adfbadf451fd318b3ea900abfca2", null ],
    [ "getTextureBorderColour", "class_ogre_1_1_texture_unit_state.html#a018bb274b11ff191a3502e2222fb9809", null ],
    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a30757c168b734902d03720e3f36c27d4", null ],
    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a363c69770217425598c716430abd159a", null ],
    [ "setTextureFiltering", "class_ogre_1_1_texture_unit_state.html#afccaca77406c883c5bfe440b7ed3c3e4", null ],
    [ "getTextureFiltering", "class_ogre_1_1_texture_unit_state.html#a41bef78e56a3b2071825f574070beed2", null ],
    [ "setTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#aa2f3464e36c93cca9bafefa4591433f3", null ],
    [ "getTextureCompareEnabled", "class_ogre_1_1_texture_unit_state.html#ac026c759650a1d3d1e340b1b6a0d4425", null ],
    [ "setTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a453e725f0367bc8bae273d4d3f990d26", null ],
    [ "getTextureCompareFunction", "class_ogre_1_1_texture_unit_state.html#a2da1174c8d8a33eeae1bfc1ee9ba67ef", null ],
    [ "setTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#abb2bc03bc72f2098e37c4240f637c5e5", null ],
    [ "getTextureAnisotropy", "class_ogre_1_1_texture_unit_state.html#ae0641061570bb6b02f2bc15f6fc76ba2", null ],
    [ "setTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#acfe54cc0ec2c1247a90094d004d77db1", null ],
    [ "getTextureMipmapBias", "class_ogre_1_1_texture_unit_state.html#a5c9a53ddea4dbdd68c1c42579ddc7fe8", null ],
    [ "setColourOperationEx", "class_ogre_1_1_texture_unit_state.html#a5f3994ce2f61c6c6fee6fe8f89c9e369", null ],
    [ "setColourOperation", "class_ogre_1_1_texture_unit_state.html#aa47f44936c3090c97d8b4179333a208b", null ],
    [ "setColourOpMultipassFallback", "class_ogre_1_1_texture_unit_state.html#a1c4dcca2a0d343dc6660b9071cd4c79f", null ],
    [ "getColourBlendMode", "class_ogre_1_1_texture_unit_state.html#a2f1ffa1b6ec8eb07bee2d1bb83ab51e5", null ],
    [ "getAlphaBlendMode", "class_ogre_1_1_texture_unit_state.html#a73b9edbd12039bbb1b339f0d7acab946", null ],
    [ "getColourBlendFallbackSrc", "class_ogre_1_1_texture_unit_state.html#a55871fd577ccae3e839ce7ca2c3e842a", null ],
    [ "getColourBlendFallbackDest", "class_ogre_1_1_texture_unit_state.html#ab68978d806e23b1cf040d95d7231ba2e", null ],
    [ "setAlphaOperation", "class_ogre_1_1_texture_unit_state.html#ae5e48cac8f87dad78d040364021b7a95", null ],
    [ "addEffect", "class_ogre_1_1_texture_unit_state.html#a63fcdc07aea7a558c046c826ae510f39", null ],
    [ "setEnvironmentMap", "class_ogre_1_1_texture_unit_state.html#a33ea31aeae9a25f1b05e2d987cbb891e", null ],
    [ "setScrollAnimation", "class_ogre_1_1_texture_unit_state.html#a45bd669bcc64ec417fe4208aa5cfd685", null ],
    [ "setRotateAnimation", "class_ogre_1_1_texture_unit_state.html#a72e3695b81f12b32762237c5de202dff", null ],
    [ "setTransformAnimation", "class_ogre_1_1_texture_unit_state.html#af56112cb1e6d144b8fd63b280d8ae350", null ],
    [ "setProjectiveTexturing", "class_ogre_1_1_texture_unit_state.html#a56edced19709cbda365eae03b590a5e1", null ],
    [ "removeAllEffects", "class_ogre_1_1_texture_unit_state.html#a2e87ea16834839d12c8c8a78e4e56302", null ],
    [ "removeEffect", "class_ogre_1_1_texture_unit_state.html#a99cc16130a5124dc6ac108d4647d2d31", null ],
    [ "isBlank", "class_ogre_1_1_texture_unit_state.html#a4de1b26e5dc01d9a73b3096de1c4853f", null ],
    [ "setBlank", "class_ogre_1_1_texture_unit_state.html#a0bfa625ec4957f67d61dd98691d632df", null ],
    [ "isTextureLoadFailing", "class_ogre_1_1_texture_unit_state.html#a8a15351e7f8c7a47e26633f1d6f15abd", null ],
    [ "retryTextureLoad", "class_ogre_1_1_texture_unit_state.html#a35ba5dfc7d336a92a1a3eccd260293eb", null ],
    [ "getEffects", "class_ogre_1_1_texture_unit_state.html#a8a92d3d54786e91d93c7ad95b1d93c74", null ],
    [ "getAnimationDuration", "class_ogre_1_1_texture_unit_state.html#a25b38aa2157538c8de784f46ab5442ac", null ],
    [ "isDefaultFiltering", "class_ogre_1_1_texture_unit_state.html#a5bb9b54d2869c429591b36f64d4361c5", null ],
    [ "setCompositorReference", "class_ogre_1_1_texture_unit_state.html#a0073a4465cc92944252d69b2671ea97d", null ],
    [ "getReferencedCompositorName", "class_ogre_1_1_texture_unit_state.html#afb47cfd7dc8d6e24dee936a6645ae316", null ],
    [ "getReferencedTextureName", "class_ogre_1_1_texture_unit_state.html#a5dbc572cbcd0354b62b08009592936a4", null ],
    [ "getReferencedMRTIndex", "class_ogre_1_1_texture_unit_state.html#a4904a58094923e9cf9e7b7e0ced22bd9", null ],
    [ "getParent", "class_ogre_1_1_texture_unit_state.html#a8ab86c68f7a74feb155c5100955c488d", null ],
    [ "_prepare", "class_ogre_1_1_texture_unit_state.html#a9ba3e0f5bee6bc207eb8819cf18a793e", null ],
    [ "_unprepare", "class_ogre_1_1_texture_unit_state.html#a719be065c5457565e744410f3ec16a3f", null ],
    [ "_load", "class_ogre_1_1_texture_unit_state.html#a152b9706e34afd01006ccdd7e2ef7c99", null ],
    [ "_unload", "class_ogre_1_1_texture_unit_state.html#a1ad9f708a4e716ca5603bb96c61960ba", null ],
    [ "hasViewRelativeTextureCoordinateGeneration", "class_ogre_1_1_texture_unit_state.html#a1a4084251e938a404d549ecb8f9db914", null ],
    [ "isLoaded", "class_ogre_1_1_texture_unit_state.html#a35e1d9894e9914eb725ab047bae276fd", null ],
    [ "_notifyNeedsRecompile", "class_ogre_1_1_texture_unit_state.html#a78895c49d27597bf3e11fc7269373124", null ],
    [ "setName", "class_ogre_1_1_texture_unit_state.html#abad476c32cafd8defc6f3c6da71dd2cb", null ],
    [ "getName", "class_ogre_1_1_texture_unit_state.html#a3e25d54715635a0ddb704757d289926e", null ],
    [ "setTextureNameAlias", "class_ogre_1_1_texture_unit_state.html#ac91d942e89e887cc7143a6073adc520c", null ],
    [ "getTextureNameAlias", "class_ogre_1_1_texture_unit_state.html#a382cebc0d7e3b61e30ec3eb625607462", null ],
    [ "applyTextureAliases", "class_ogre_1_1_texture_unit_state.html#a1d18cb7a792b05d9ffd6192d7f9a252f", null ],
    [ "_notifyParent", "class_ogre_1_1_texture_unit_state.html#a69a867f544a08845a86acc421476c3e4", null ],
    [ "_getTexturePtr", "class_ogre_1_1_texture_unit_state.html#a9c9bc1ebd44275f7c716c9aaab1452ff", null ],
    [ "_getTexturePtr", "class_ogre_1_1_texture_unit_state.html#addfe8bb3fabe45d6f5e95c774caab2d7", null ],
    [ "_setTexturePtr", "class_ogre_1_1_texture_unit_state.html#abaa17fc5f6b4d96bfe19ecc6c78a331e", null ],
    [ "_setTexturePtr", "class_ogre_1_1_texture_unit_state.html#a6236e0e398c153980ff06f13e58a667b", null ],
    [ "calculateSize", "class_ogre_1_1_texture_unit_state.html#a2c9d0e4e1188041093e8b2c95dc07359", null ],
    [ "_getAnimController", "class_ogre_1_1_texture_unit_state.html#aac051a780fa7e8ccd891c71d5dfb001b", null ],
    [ "_getLocalSampler", "class_ogre_1_1_texture_unit_state.html#a983cd4d8de66d003dc173f5738fab245", null ],
    [ "RenderSystem", "class_ogre_1_1_texture_unit_state.html#a06b786d8e0847dfe9cc15e1dea308fcd", null ],
    [ "TAM_WRAP", "class_ogre_1_1_texture_unit_state.html#a9d12f77b02eacd0da7dcec2ac654c256", null ],
    [ "TAM_MIRROR", "class_ogre_1_1_texture_unit_state.html#a7f29d334eabef6ca15cc1e3a1d594467", null ],
    [ "TAM_CLAMP", "class_ogre_1_1_texture_unit_state.html#aaa593803cf70c8a67f24d4b74ad2ad77", null ],
    [ "TAM_BORDER", "class_ogre_1_1_texture_unit_state.html#acced150b0dc0d1d64b0802dbe4cf7db1", null ],
    [ "TAM_UNKNOWN", "class_ogre_1_1_texture_unit_state.html#a27d31e5a5ad06d018986d13b12fd4b41", null ]
];